@@ -1,12 +1,18 @@
 `get.models` <-
 function(dd, subset = delta <= 4, ...) {
 
+	#subset <- if (missing(subset)) quote() else substitute(subset)
 	subset <- eval(substitute(subset), envir = dd, enclos = parent.frame())
 	gmod <- attr(dd, "global")
 	frm <- attr(dd, "formulas")[subset]
 
-	sgmod <- substitute(gmod)
-	models <- lapply(frm, function(.x) eval(call("update", sgmod, .x), sys.parent(3)))
+	arg <- list(substitute(gmod), NA, ...)
+	env <- attr(tryCatch(terms(gmod), error=function(...) terms(formula(gmod))),".Environment")
+
+	models <- lapply(frm, function(.x) {
+		arg[[2]] <- .x
+		do.call("update", arg, quote = TRUE, envir=env)
+	})
 
 	if (!is.null(attr(dd, "rank.call"))) {
   		attr(models, "rank.call") <- attr(dd, "rank.call")
@@ -14,4 +20,3 @@ function(dd, subset = delta <= 4, ...) {
 
 	return(models)
 }
-
