@@ -1,7 +1,6 @@
 `getAllTerms.default` <-
 function(x, ...) getAllTerms(as.formula(formula(x)), ...)
 
-
 `getAllTerms.terms` <-
 function(x, offset = TRUE, ...) {
 	if (!is.null(attr(x, "offset"))){
@@ -46,12 +45,9 @@ function(x, offset = TRUE, ...) {
 	return(ret)
 }
 
-
-
 `getAllTerms.formula` <-
 function(x, ...) getAllTerms.terms(terms(x), ...)
 
-
 `getAllTerms.lme` <-
 function(x, ...) {
 	ret <- getAllTerms(terms(x))
@@ -74,14 +70,19 @@ function(x, ...) {
 	return(ret)
 }
 
-
-
-
 `getAllTerms.glmer` <- # For backwards compatibility
 `getAllTerms.lmer` <-  # with older versions of lme4
 `getAllTerms.mer` <-
 function(x, ...) getAllTerms(formula(x), ...)
 
+# Apparently there is no (explicit) intercept in coxph, but 'terms' gives
+# attr(,"intercept") == 1.
+`getAllTerms.coxph` <- function (x, ...) {
+	ret <- getAllTerms.default(x)
+	attr(ret,"intercept") <- 0
+	return(ret)
+}
+
 
 `getAllTerms` <-
 function(x, ...) UseMethod("getAllTerms")
